yt.fields.fluid\_vector\_fields module
======================================

.. automodule:: yt.fields.fluid_vector_fields
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
